% Master Thesis Eirik Nesjo
% create_heave_cases.m
%
% This file generates the different cases to perform a study of the piston-mode in heave for different periods.
% 
% The codes are not well documented, but a small inroduction is given here.
% 
% Installation Requirements
% - OpenFOAM 2.3.0
% - PVC3D
% - GNU Octave
% - GNU M4
%
% The differnt periods are defined in the array "cases_periods"
% A campaign folder will be created, within the cases are produced.
% After this code has been excecuted, a "Allrun" file can be excecuted from the terminal.
%
% The domain and mesh is fixed in the template folder. Check the system/topoSetDict file in order to alter the hull
% 
% Figures Exported after each Run
% - Moonpool Elevatoin
% 

template = 'oscillatingHull';

campaign = 'testhalla'

template_l = 0.256;
g = 9.81;

dimless = g/template_l;

cases_finalHeaveAmp = 0.01; 

cases_periods = 0.5:0.1:1.5;



%check if folder exists, if not create the folder
if exist(strcat(campaign,'/'))
    campaign
else
    mkdir(campaign)
end

fileID2 = fopen(strcat('Allrun'),'w');
fprintf(fileID2,'#!/bin/sh \n');

for i=1:length(cases_periods)
    
    cases_period = cases_periods(i)
    cases_heaveFreq = 1/cases_period
    cases_heaveOmega  = (2*pi)/cases_period
    cases_rampStartTimeHeave = 0;
    cases_rampDurationHeave = 10*cases_period;

    cases_runtime = 40 * cases_period;
    cases_dt = cases_period / 100;
    
    casename = strcat(campaign,'/case',num2str(cases_period),'');
    
    if exist(strcat(casename,'done'),'dir') == 0
        
    casename
    
    copyfile(template,casename);
    
    save(strcat(casename,'/parameters.matlab'),'cases_finalHeaveAmp','cases_rampDurationHeave','cases_heaveOmega','-ascii');
    
    fileID = fopen(strcat(casename,'/parameters.m4'),'w');

    fprintf(fileID,'define(cases_rampStartTimeHeave, %.4f)\n',cases_rampStartTimeHeave);
    fprintf(fileID,'define(cases_rampDurationHeave, %.4f)\n',cases_rampDurationHeave);
    fprintf(fileID,'define(cases_finalHeaveAmp, %.4f)\n',cases_finalHeaveAmp);
    fprintf(fileID,'define(cases_heaveOmega, %.4f)\n',cases_heaveOmega);
    fprintf(fileID,'define(cases_heaveFreq, %.4f)\n',cases_heaveFreq);
    fprintf(fileID,'define(cases_runtime, %.4f)\n',cases_runtime);
    
    fprintf(fileID,'define(cases_dt, %.4f)\n',cases_dt);
    
    fclose(fileID);
    
    fprintf(fileID2,'(cd %s && ./Allrun) \n',casename);
    fprintf(fileID2,'mv %s %s \n \n \n',casename,strcat(casename,'done'));
    
    end

end

fclose(fileID2);

