% Master Thesis Eirik Nesjo
% create_from_template.m
%
% This file generates the different cases to perform a study of the piston-mode for different velocities
% 
% The codes are not well documented, but a small inroduction is given here.
% 
% Installation Requirements
% - OpenFOAM 2.3.0
% - PVC3D
% - GNU Octave
% - GNU M4
%
% The differnt cases are defined in the matrix "case_data"
% A campaign folder will be created, within the cases are produced.
% After this code has been excecuted, a "Allrun" file can be excecuted from the terminal.
%
% Figures Exported after each Run
% - Moonpool Elevatoin
% - Courant Number
% - Executional time 
% - Velocities from probes below the moonpool
% 
% case_data
% 1 - Length of Moonpool
% 2 - Deepth of Moonpool
% 3 - Length of forship
% 4 - Length of aftship
% 5 - Deepth of wavetank
% 6 - Thickness of wavetank
% 
% 7  - Mesh parameter
% 8  - Mesh parameter
% 9  - Mesh parameter
% 10 - Mesh parameter
% 11 - Mesh parameter
%
% 12 - Velocity of hull
% 13 - Start Time
% 14 - End Time
% 15 - Ramp time
% 16 - Timestep
% 17 - Output interval parameters of interest
% 18 - Output interval timestep folder 
%
%

%example data
run_cases = 1:4;
writeAllfile = 1;

campaign = '4june_d06'

ma = 60;
mb = 90;

l = 0.256;
d = l*0.6;

temp_int = 1;
case_name{temp_int} = '040';
case_data(temp_int,:) = [l d 1.9720 1.9720 4.2 1 mb mb mb ma d/(l/ma) 0.40 0.0 500 25 0.005 0.05 10];
temp_int = temp_int +1;

case_name{temp_int} = '055';
case_data(temp_int,:) = [l d 1.9720 1.9720 4.2 1 mb mb mb ma d/(l/ma) 0.55 0.0 500 25 0.003125 0.05 10];
temp_int = temp_int +1;

case_name{temp_int} = '065';
case_data(temp_int,:) = [l d 1.9720 1.9720 4.2 1 mb mb mb ma d/(l/ma) 0.65 0.0 500 25 0.003125 0.05 10];
temp_int = temp_int +1;

case_name{temp_int} = '060';
case_data(temp_int,:) = [l d 1.9720 1.9720 4.2 1 mb mb mb ma d/(l/ma) 0.60 0.0 500 25 0.003125 0.05 10];

for j=1:length(case_name)
CFL_test(j,1) = (case_data(j,12)*case_data(j,16))/(case_data(j,1)/case_data(j,10));
end
%print expected CFL values 
CFL_test

%check if folder exists, if not create the folder
if exist(strcat(campaign,'/'))
    campaign
else
    mkdir(campaign)
end

%backup current file
copyfile(strcat(mfilename,'.m'),strcat(campaign,'/',campaign,'_',mfilename,'.m'));

for j=1:length(run_cases)

    i=run_cases(j)
    
dummy = 0;

case_i = case_data(i,:);
current_case = case_i;


geo_moonpool_length = case_i(1);
geo_moonpool_depth = case_i(2);

geo_forship = case_i(3);
geo_aftship = case_i(4);
geo_wavetank_depth = case_i(5);
geo_2D_thickness = case_i(6);

mesh_box1_cell = [case_i(7) case_i(8)];
mesh_box2_cell = [dummy dummy];
mesh_box3_cell = [case_i(9) dummy];
mesh_box4_cell = [case_i(10) case_i(11)];

case_velocity_u = case_i(12);

case_OFpara_startTime = case_i(13);
case_OFpara_endTime = case_i(14);
case_OFpara_rampTime = case_i(15);
case_OFpara_deltaT = case_i(16);
case_OFpara_logInterval = case_i(17);
case_OFpara_writeInterval = case_i(18);

l_mp_box = geo_moonpool_length/mesh_box4_cell(1);
h_mp_box = geo_moonpool_depth/mesh_box4_cell(2);

temp(1) = blockmeshgrading_b(geo_aftship,mesh_box1_cell(1),l_mp_box);
temp(2) = blockmeshgrading_a(geo_forship,mesh_box1_cell(1),l_mp_box);
temp(3) = blockmeshgrading_a(geo_wavetank_depth,mesh_box1_cell(2),h_mp_box);

mesh_box1_grading = [temp(1) temp(3) 1];
mesh_box2_grading = [1 temp(3) 1];
mesh_box3_grading = [temp(2) temp(3) 1];
mesh_box4_grading = [1 1 1];

copyfile('moonpool',strcat(campaign,'/',case_name{i}));


fileID = fopen(strcat(campaign,'/',case_name{i},'/parameters.m4'),'w');

fprintf(fileID,'define(B, %.8f)\n',geo_moonpool_length);
fprintf(fileID,'define(D, %.8f)\n',geo_moonpool_depth);
fprintf(fileID,'define(For_ship, %.8f)\n',geo_forship);
fprintf(fileID,'define(Aft_ship, %.8f)\n',geo_aftship);
fprintf(fileID,'define(Tank_depth, %.8f)\n',geo_wavetank_depth);
fprintf(fileID,'define(box1_x_cell,%.0f)\n',mesh_box1_cell(1));
fprintf(fileID,'define(box1_y_cell,%.0f)\n',mesh_box1_cell(2));
fprintf(fileID,'define(box4_x_cell,%.0f)\n',mesh_box4_cell(1));
fprintf(fileID,'define(box4_y_cell,%.0f)\n',mesh_box4_cell(2));
fprintf(fileID,'define(box3_x_cell,%.0f)\n',mesh_box3_cell(1));
fprintf(fileID,'define(thickness,%.8f)\n',geo_2D_thickness);
fprintf(fileID,'define(box1_grading, simpleGrading (%.8f %.8f %.8f))\n',mesh_box1_grading(1),mesh_box1_grading(2),mesh_box1_grading(3));
fprintf(fileID,'define(box2_grading, simpleGrading (%.8f %.8f %.8f))\n',mesh_box2_grading(1),mesh_box2_grading(2),mesh_box2_grading(3));
fprintf(fileID,'define(box3_grading, simpleGrading (%.8f %.8f %.8f))\n',mesh_box3_grading(1),mesh_box3_grading(2),mesh_box3_grading(3));
fprintf(fileID,'define(box4_grading, simpleGrading (%.8f %.8f %.8f))\n',mesh_box4_grading(1),mesh_box4_grading(2),mesh_box4_grading(3));
fprintf(fileID,'define(velocity_u,%.8f)\n',case_velocity_u);
fprintf(fileID,'define(para_startTime,%.8f)\n',case_OFpara_startTime);
fprintf(fileID,'define(para_endTime,%.8f)\n',case_OFpara_endTime);
fprintf(fileID,'define(para_rampTime,%.8f)\n',case_OFpara_rampTime);
fprintf(fileID,'define(para_deltaT,%.8f)\n',case_OFpara_deltaT);
fprintf(fileID,'define(para_logInterval,%.8f)\n',case_OFpara_logInterval);
fprintf(fileID,'define(para_writeInterval,%.8f)\n',case_OFpara_writeInterval);
fclose(fileID);

save(strcat(campaign,'/',case_name{i},'/parameters.matlab'),'case_i','-ascii');

    fileID3 = fopen(strcat(campaign,'/Allrun_',case_name{i}),'w');
	fprintf(fileID3,'#!/bin/sh \n');
	fprintf(fileID3,'(cd %s && ./pre) \n',case_name{i});
	fprintf(fileID3,'(cd %s && ./run) \n',case_name{i});
	fprintf(fileID3,'(cd %s && ./force) \n',case_name{i});
	fprintf(fileID3,'#(cd %s && ./plot) \n',case_name{i});
	fprintf(fileID3,'(cd %s && ./backup) \n',case_name{i});
	fprintf(fileID3,'(cd %s && ./clean) \n',case_name{i});
	fprintf(fileID3,'mv %s %s \n \n \n',case_name{i},strcat(case_name{i},'done'));
	fclose(fileID3);

end


if writeAllfile == 1

	fileID2 = fopen(strcat(campaign,'/','Allrun'),'w');
	fprintf(fileID2,'#!/bin/sh \n');

	for j=1:length(run_cases)

    i=run_cases(j);

	fprintf(fileID2,'(cd %s && ./pre) \n',case_name{i});
	fprintf(fileID2,'(cd %s && ./run) \n',case_name{i});
	fprintf(fileID2,'(cd %s && ./force) \n',case_name{i});
	fprintf(fileID2,'#(cd %s && ./plot) \n',case_name{i});
	fprintf(fileID2,'(cd %s && ./backup) \n',case_name{i});
	fprintf(fileID2,'(cd %s && ./clean) \n',case_name{i});
	fprintf(fileID2,'mv %s %s \n \n \n',case_name{i},strcat(case_name{i},'done'));

	

	end
	fclose(fileID2);
end
