/*--------------------------------*- C++ -*----------------------------------*\
| =========                 |                                                 |
| \\      /  F ield         | OpenFOAM: The Open Source CFD Toolbox           |
|  \\    /   O peration     | Version:  2.3.0                                 |
|   \\  /    A nd           | Web:      www.OpenFOAM.org                      |
|    \\/     M anipulation  |                                                 |
\*---------------------------------------------------------------------------*/
FoamFile
{
    version     2.0;
    format    ascii;
    class       dictionary;
    object      blockMeshDict;
}
// * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * //
// General m4 macros

changecom(//)changequote([,]) dnl>
define(calc, [esyscmd(perl -e 'use Math::Trig; print ($1)')]) dnl>
define(VCOUNT, 0)
define(vlabel, [[// ]Vertex $1 = VCOUNT define($1, VCOUNT)define([VCOUNT], incr(VCOUNT))])

define(hex2D, hex (b$1 b$2 b$3 b$4 f$1 f$2 f$3 f$4))
define(quad2D, (b$1 b$2 f$2 f$1))
define(frontQuad, (f$1 f$2 f$3 f$4))
define(backQuad, (b$1 b$4 b$3 b$2))

// * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * //
// User-defined parameters
convertToMeters 1;
include(parameters.m4)


//consequences

define(box3_y_cell,box1_y_cell) //Hull to bottom
define(box2_x_cell,box4_x_cell) //Moonpool Length
define(box2_y_cell,box1_y_cell) //Downward from moonpool opening to bottom


// * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * //
// Derived parameters

define(box1_ax, 0) 
define(box1_ay, -D) 
define(box1_bx, 0) 
define(box1_by, -calc(Tank_depth+D)) 
define(box1_cx, For_ship) 
define(box1_cy, -calc(Tank_depth+D))  
define(box1_dx, For_ship) 
define(box1_dy, -D) 

define(box2_ax, For_ship) 
define(box2_ay, -D)
define(box2_bx, For_ship) 
define(box2_by, -calc(Tank_depth+D)) 
define(box2_cx, calc(For_ship+B)) 
define(box2_cy, -calc(Tank_depth+D)) 
define(box2_dx, calc(For_ship+B)) 
define(box2_dy, -D)

define(box3_ax, calc(For_ship+B)) 
define(box3_ay, -D)
define(box3_bx, calc(For_ship+B)) 
define(box3_by, -calc(Tank_depth+D)) 
define(box3_cx, calc(For_ship+B+Aft_ship)) 
define(box3_cy, -calc(Tank_depth+D)) 
define(box3_dx, calc(For_ship+B+Aft_ship)) 
define(box3_dy, -D)

define(box4_ax, For_ship) 
define(box4_ay, 0) 
define(box4_bx, For_ship) 
define(box4_by, -D) 
define(box4_cx, calc(For_ship+B)) 
define(box4_cy, -D) 
define(box4_dx, calc(For_ship+B)) 
define(box4_dy, 0) 


// * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * //
// Parametric description

vertices
(
    (box1_ax box1_ay 0) vlabel(fp0)
    (box1_bx box1_by 0) vlabel(fp1)
    (box1_cx box1_cy 0) vlabel(fp2)
    (box1_dx box1_dy 0) vlabel(fp3)

    (box2_cx box2_cy 0) vlabel(fp4)
    (box2_dx box2_dy 0) vlabel(fp5)

    (box3_cx box3_cy 0) vlabel(fp6)
    (box3_dx box3_dy 0) vlabel(fp7)

    (box4_ax box4_ay 0) vlabel(fp8)
    (box4_dx box4_dy 0) vlabel(fp9)

    (box1_ax box1_ay thickness) vlabel(bp0)
    (box1_bx box1_by thickness) vlabel(bp1)
    (box1_cx box1_cy thickness) vlabel(bp2)
    (box1_dx box1_dy thickness) vlabel(bp3)

    (box2_cx box2_cy thickness) vlabel(bp4)
    (box2_dx box2_dy thickness) vlabel(bp5)

    (box3_cx box3_cy thickness) vlabel(bp6)
    (box3_dx box3_dy thickness) vlabel(bp7)

    (box4_ax box4_ay thickness) vlabel(bp8)
    (box4_dx box4_dy thickness) vlabel(bp9)

);



blocks
(
    // box1
    hex2D(p0, p3, p2, p1)
    (box1_x_cell box1_y_cell 1)
    box1_grading

    /// box2
    hex2D(p3, p5, p4, p2)
    (box2_x_cell box2_y_cell 1)
    box2_grading

    // box3
    hex2D(p5, p7, p6, p4)
    (box3_x_cell box3_y_cell 1)
    box3_grading

    // box4
    hex2D(p8, p9, p5, p3)
    (box4_x_cell box4_y_cell 1)
    box4_grading
);


patches
(
    patch inlet
    (
        quad2D(p1, p0)
    )
    patch outlet
    (
        quad2D(p7, p6)
    )
    patch moonpool_water_surface
    (
        quad2D(p8, p9)
    )
    wall hull1
    (
        quad2D(p0, p3)
    )
    wall hull2
    (
        quad2D(p5, p7)
    )
    wall moonpool_wall1
    (
        quad2D(p3, p8)
    )
    wall moonpool_wall2
    (
        quad2D(p9, p5)
    )
    patch bottom
    (
        quad2D(p2, p1)
        quad2D(p4, p2)
        quad2D(p6, p4)
    )
    empty front
    (
        frontQuad(p0, p3, p2, p1)
        frontQuad(p3, p5, p4, p2)
        frontQuad(p5, p7, p6, p4)
        frontQuad(p8, p9, p5, p3)
    )

    empty back
    (
        backQuad(p0, p3, p2, p1)
        backQuad(p3, p5, p4, p2)
        backQuad(p5, p7, p6, p4)
        backQuad(p8, p9, p5, p3)
    )
);


// ************************************************************************* //

